@@ -7,7 +7,7 @@
  *      implementation of the pqxx::connection and pqxx::lazyconnection classes.
  *   Different ways of setting up a backend connection.
  *
- * Copyright (c) 2001-2003, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2001-2004, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -42,7 +42,7 @@ pqxx::connection::connection(const char ConnInfo[]) :
 }
 
 // Work around problem with Sun CC 5.1
-pqxx::connection::~connection()
+pqxx::connection::~connection() throw ()
 {
 }
 
@@ -81,13 +81,13 @@ pqxx::lazyconnection::lazyconnection(const char ConnInfo[]) :
 
 
 // Work around problem with Sun CC 5.1
-pqxx::lazyconnection::~lazyconnection()
+pqxx::lazyconnection::~lazyconnection() throw ()
 {
 }
 
 
 // Work around problem with Sun CC 5.1
-pqxx::asyncconnection::~asyncconnection()
+pqxx::asyncconnection::~asyncconnection() throw ()
 {
 }
 
