@@ -7,7 +7,7 @@
  *      implementation of the pqxx::tablestream class.
  *   pqxx::tablestream provides optimized batch access to a database table
  *
- * Copyright (c) 2001-2003, Jeroen T. Vermeulen <jtv@xs4all.nl>
+ * Copyright (c) 2001-2004, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
  * See COPYING for copyright license.  If you did not receive a file called
  * COPYING with this source code, please notify the distributor of this mistake,
@@ -25,36 +25,25 @@ using namespace PGSTD;
 
 pqxx::tablestream::tablestream(transaction_base &STrans, 
                                const string &SName, 
-			       const string &Null) :
-  m_Trans(STrans),
-  m_Name(SName),
+			       const string &Null,
+			       const char Classname[]) :
+  internal::transactionfocus(STrans, SName, Classname),
   m_Null(Null),
   m_Finished(false)
 {
 }
 
 
-pqxx::tablestream::~tablestream()
+pqxx::tablestream::~tablestream() throw ()
 {
 }
 
 
-void pqxx::tablestream::register_me()
-{
-  m_Trans.RegisterStream(this);
-}
-
-
 void pqxx::tablestream::base_close()
 {
   m_Finished = true;
-  m_Trans.UnregisterStream(this);
+  unregister_me();
 }
 
 
-void pqxx::tablestream::RegisterPendingError(const string &Err) throw ()
-{
-  m_Trans.RegisterPendingError(Err);
-}
-
 
