@@ -39,7 +39,7 @@ int main(int, char *argv[])
     cout << "Retrieving initial result..." << endl;
     const int res_1 = P.retrieve(id_1).at(0).at(0).as<int>();
     cout << " - result was " << res_1 << endl;
-    if (res_1 != 1) throw logic_error("Expected 1, got " + ToString(res_1));
+    if (res_1 != 1) throw logic_error("Expected 1, got " + to_string(res_1));
 
     // We should *not* get a result for the query behind the error
     cout << "Restrieving post-error result..." << endl;
